@@ -25,15 +25,15 @@ def print_info(func):
         if TRACK_TIME:
             timer.stop() # Stop timer
 
-        print_('\n%s' % func.__name__)
+        print_('\n{0}'.format(func.__name__))
         print_('============================')
         if func.__doc__:
-            print_('""" %s """' % func.__doc__.strip())
+            print_('""" {0} """'.format(func.__doc__.strip()))
         print_('----------------------------')
         if result is not None:
             print_(result)
         if TRACK_TIME:
-            print_('done in %s seconds' % timer.duration)
+            print_('done in {0} seconds'.format(timer.duration))
 
         return result
     return inner
@@ -58,7 +58,7 @@ class StarbaseClientSpeedTest(unittest.TestCase):
         num_rows = 10000
         for i in range(0, num_rows):
             b.insert(
-                'aaa_%s' % i,
+                'aaa_{0}'.format(i),
                 {
                     'users': {'id': '1', 'pass': 'bla'},
                     'groups': {'id': '1', 'role': 'admins'},
@@ -68,8 +68,8 @@ class StarbaseClientSpeedTest(unittest.TestCase):
         r = b.commit(finalize=True)
         #tm.stop()
 
-        #print 'done in %s seconds' % tm.duration
-        #print 'which makes it %s inserts per second' % (tm.duration / num_rows)
+        #print 'done in {0} seconds'.format(tm.duration)
+        #print 'which makes it {0} inserts per second'.format(tm.duration / num_rows)
         #return None
 
 if __name__ == '__main__':
